==> netjfwatcher1.3.5_ApacheDerby.tar.gz: netjfwatcher/snmp/preference/SnmpPreference.java <==
/*
 * Created on 2004/03/24
 *
 */
package netjfwatcher.snmp.preference;


/**
 * SNMP vtFXNXłB
 *
 * @author Yoshimasa Matsumoto
 * @version 1.0
 */
public abstract class SnmpPreference {
    /** ftHg SNMP Portԍ */
    public static final int SNMP_PORT = 161;

    /** ftHg SNMP Trap Portԍ */
    public static final int SNMP_TRAP_PORT = 162;

    /** UDP MpPbgobt@[TCY */
    public static final int IN_DATA_PACKET_MAX = 512;

    /** SNMP o[W 1 */
    public static final int SNMP_VERSION_1 = 0;

    /** <p>SNMP o[W 2c</p> */
    public static final int SNMPV2C = 1;

    /** <p>SNMP o[W 3</p> */
    public static final int SNMPV3 = 3;

    /** TrapMe[u\ɂSnmp V1 Version */
    public static final String SNMPV1_DESCRIPTION = "SNMPV1";

    /** TrapMe[u\ɂSnmp V2C Version */
    public static final String SNMPV2_DESCRIPTION = "SNMPV2C";

    /** TrapMe[u\ɂSnmp V3 Version */
    public static final String SNMPV3_DESCRIPTION = "SNMPV3";

    /** SNMPĎx0(ĎȂ) Description */
    public static final String SNMP_LEVEL0_DESCRIPTION = "No SNMP";
    public static final int SNMP_LEVEL0 = 0;
    public static final String SNMP_LEVEL0_CODE_STRING = "0";

    /** SNMPĎx1(\`Ď) Description */
    public static final String SNMP_LEVEL1_DESCRIPTION = "SNMP Configration";
    public static final int SNMP_LEVEL1 = 1;
    public static final String SNMP_LEVEL1_CODE_STRING = "1";

    /** SNMPĎx2(ifOctetsvyэ\`Ď) Description */
    public static final String SNMP_LEVEL2_DESCRIPTION = "SNMP ifOctets";
    public static final int SNMP_LEVEL2 = 2;
    public static final String SNMP_LEVEL2_CODE_STRING = "2";

    /** SNMPĎx3(CPUϕדvyэ\`Ď) Description */
    public static final String SNMP_LEVEL3_DESCRIPTION = "SNMP laLoad";
    public static final int SNMP_LEVEL3 = 3;
    public static final String SNMP_LEVEL3_CODE_STRING = "3";

    /** SNMPĎx4(Diskv̓vyэ\`Ď) Description */
    public static final String SNMP_LEVEL4_DESCRIPTION = "SNMP disk";
    public static final int SNMP_LEVEL4 = 4;
    public static final String SNMP_LEVEL4_CODE_STRING = "4";

    /**
     * SNMP}l[WSocket Timeout(ms)
     * ftHg6sec
     */
    public static final int SNMP_MANAGER_SOCKET_TIMEOUT = 6000;

    /**
     * SNMP}l[W̃gC
     */
    public static final int SNMP_MANAGER_SOCKET_RETRY = 3;

    /**
     * ErrorStatus "FormatError"
     *
     * Reference.
     *
     * Error Status Description
     *
     * -1   "FormatError"
     *  0   "NoError"
     *  1   "TooBig"
     *  2   "NoSuchName"
     *  3   "BadValue"
     *  4   "ReadOnly"
     *  5   "GenError"
     * Else "UnknownError
     */
    public static final int ERROR_STATUS_FORMATERROR = -1;

    /** Error Status "NoError"*/
    public static final int ERROR_STATUS_CORRECT = 0;

    /** Error Index Correct */
    public static final int ERROR_INDEX_CORRECT = 0;

    /** ErrorStatus "TooBig"*/
    public static final int ERROR_STATUS_TOOBIG = 1;

    /** ErrorStatus "NoSuchName"*/
    public static final int ERROR_STATUS_NOSUCHNAME = 2;

    /** ErrorStatus "BadValue"*/
    public static final int ERROR_STATUS_BADVALUE = 3;

    /** ErrorStatus "ReadOnly"*/
    public static final int ERROR_STATUS_READONLY = 4;

    /** ErrorStatus "GenError"*/
    public static final int ERROR_STATUS_GENERROR = 5;

    /** ErrorStatus "NoAcess"*/
    public static final int ERROR_STATUS_NOACCESS = 6;

    /** ErrorStatus "Wrong type"*/
    public static final int ERROR_STATUS_WRONG_TYPE = 7;

    /** ErrorStatus "Wrong length"*/
    public static final int ERROR_STATUS_WRONG_LENGTH = 8;

    /** ErrorStatus "Wrong value"*/
    public static final int ERROR_STATUS_WRONG_VALUE = 10;

    /** ErrorStatus "No creation"*/
    public static final int ERROR_STATUS_NO_CREATION = 11;

    /** ErrorStatus "Inconsistent value"*/
    public static final int ERROR_STATUS_INCONSISTENT_VALUE = 12;

    /** ErrorStatus "Resource UnAvailable"*/
    public static final int ERROR_STATUS_RESOURCE_UNAVAILABLE = 13;

    /** ErrorStatus "Commit failed"*/
    public static final int ERROR_STATUS_COMMIT_FAILED = 14;

    /** ErrorStatus "Undo failed"*/
    public static final int ERROR_STATUS_UNDO_FAILED = 15;

    /** ErrorStatus "Authorization error"*/
    public static final int ERROR_STATUS_AUTHORIZATION_ERROR = 16;

    /** ErrorStatus "No writable"*/
    public static final int ERROR_STATUS_NO_WRITABLE = 17;

    /** ErrorStatus "Inconsistent name"*/
    public static final int ERROR_STATUS_INCONSISTENT_NAME = 18;

    /** coldStart Generic Trap-code */
    public static final int COLDSTART = 0;

    /** warmStart Generic Trap-code */
    public static final int WARMSTART = 1;

    /** linkDown Generic Trap-code */
    public static final int LINKDOWN = 2;

    /** linkUp Generic Trap-code */
    public static final int LINKUP = 3;

    /** authenticationFailure Generic Trap-code */
    public static final int AUTHENTICATIONFAILURE = 4;

    /** egpNeighborLoss Generic Trap-code */
    public static final int EGPNEIGHBORLOS = 5;

    /** enterpriseSpecific Generic Trap-code */
    public static final int ENTERPRISESPECIFIC = 6;

    /** ifInOctets MINebg */
    public static final String IFINOCTETS_OID = "1.3.6.1.2.1.2.2.1.10";

    /** ifOutOctets MINebg */
    public static final String IFOUTOCTETS_OID = "1.3.6.1.2.1.2.2.1.16";

    /** Sysup Time OID */
    public static final String SNMP_SYSUPTIME_OID = "1.3.6.1.2.1.1.3.0";

    /**
     * TrapType defines the type of SNMPv2/SNMPv3 trap,
     * this is defined in the SNMPv2-MIB as snmpTrapOID.0
     * (.1.3.6.1.6.3.1.1.4.1.0) with an OID value of one
     *  of the following
     */
    public static final String SNMP_TRAP_OID = "1.3.6.1.6.3.1.1.4.1.0";

    /** coldStart OID */
    public static final String COLDSTART_OID = "1.3.6.1.6.3.1.1.5.1";

    /** warmStart OID */
    public static final String WARMSTART_OID = "1.3.6.1.6.3.1.1.5.2";

    /** linkDown OID */
    public static final String LINKDOWN_OID = "1.3.6.1.6.3.1.1.5.3";

    /** linkUp OID */
    public static final String LINKUP_OID = "1.3.6.1.6.3.1.1.5.4";

    /** authenticationFailure OID */
    public static final String AUTHENTICATIONFAILURE_OID =
        "1.3.6.1.6.3.1.1.5.5";

    /** egpNeighborLoss OID */
    public static final String EGPNEIGHBORLOS_OID = "1.3.6.1.6.3.1.1.5.6";

    /** Unknown packet data unit OID */
    public static final String UNKONOWN_PACKET_DATA_UNIT =
        "1.3.6.1.6.3.11.2.1.3.0";

    /** Unknown packet data unit description */
    public static final String UNKONOWN_PACKET_DATA_UNIT_DESCRIPTION =
        "Unknown packet data unit";

    /** The value of the varbind shows the engine ID OID */
    public static final String SHOW_ENGINEID = "1.3.6.1.6.3.12.1.5.0";

    /** The value of the varbind shows the engine ID description */
    public static final String SHOW_ENGINEID_DESCRIPTION =
        "The value of the varbind shows the engine ID";

    /** Correct description */
    public static final String CORRECT_DESCRIPTION = "Normal";

    /** Unsupported security level of report OID */
    public static final String UNSUPPORTED_SECURITY_LEVEL =
        "1.3.6.1.6.3.15.1.1.1.0";

    /** Unsupported security level of report description */
    public static final String UNSUPPORTED_SECURITY_LEVEL_DESCRIPTION =
        "Unsupported security level";

    /** SNMP V3 Not inTime packet report OID */
    public static final String NOT_IN_TIME_PACKET = "1.3.6.1.6.3.15.1.1.2.0";

    /** SNMP V3 Not inTime packet report description */
    public static final String NOT_IN_TIME_PACKET_DESCRIPTION =
        "Not in time packet";

    /** SNMP V3 Unknown user name OID */
    public static final String UNKNOWN_USER_NAME = "1.3.6.1.6.3.15.1.1.3.0";

    /** SNMP V3 Unknown user name description */
    public static final String UNKNOWN_USER_NAME_DESCRIPTION =
        "Unknown user name";

    /** SNMP V3 Unknown engine ID OID */
    public static final String UNKNOWN_ENGINE_ID = "1.3.6.1.6.3.15.1.1.4.0";

    /** SNMP V3 Unknown engine ID description */
    public static final String UNKNOWN_ENGINE_ID_DESCRIPTION =
        "Unknown engine ID";

    /** SNMP V3 Wrong digest OID*/
    public static final String WRONG_DIGEST = "1.3.6.1.6.3.15.1.1.5.0";

    /** SNMP V3 Wrong digest description */
    public static final String WRONG_DIGEST_DESCRIPTION = "Wrong digest";

    /** SNMP V3 Descryption error OID */
    public static final String DECRYPTION_ERROR = "1.3.6.1.6.3.15.1.1.6.0";

    /** SNMP V3 Descryption error description */
    public static final String DECRYPTION_ERROR_DESCRIPTION =
        "Descryption error";
}

==> netjfwatcher1.3.7_ApacheDerby.tar.gz: netjfwatcher/snmp/preference/SnmpPreference.java <==
/*
 * Created on 2004/03/24
 *
 */
package netjfwatcher.snmp.preference;


/**
 * SNMP vtFXNXłB
 *
 * @author Yoshimasa Matsumoto
 * @version 1.0
 */
public abstract class SnmpPreference {
    /** ftHg SNMP Portԍ */
    public static final int SNMP_PORT = 161;

    /** ftHg SNMP Trap Portԍ */
    public static final int SNMP_TRAP_PORT = 162;

    /** UDP MpPbgobt@[TCY */
    public static final int IN_DATA_PACKET_MAX = 512;

    /** SNMP o[W 1 */
    public static final int SNMP_VERSION_1 = 0;

    /** <p>SNMP o[W 2c</p> */
    public static final int SNMPV2C = 1;

    /** <p>SNMP o[W 3</p> */
    public static final int SNMPV3 = 3;

    /** TrapMe[u\ɂSnmp V1 Version */
    public static final String SNMPV1_DESCRIPTION = "SNMPV1";

    /** TrapMe[u\ɂSnmp V2C Version */
    public static final String SNMPV2_DESCRIPTION = "SNMPV2C";

    /** TrapMe[u\ɂSnmp V3 Version */
    public static final String SNMPV3_DESCRIPTION = "SNMPV3";

    /** SNMPĎx0(ĎȂ) Description */
    public static final String SNMP_LEVEL0_DESCRIPTION = "No SNMP";
    public static final int SNMP_LEVEL0 = 0;
    public static final String SNMP_LEVEL0_CODE_STRING = "0";

    /** SNMPĎx1(\`Ď) Description */
    public static final String SNMP_LEVEL1_DESCRIPTION = "SNMP Configration";
    public static final int SNMP_LEVEL1 = 1;
    public static final String SNMP_LEVEL1_CODE_STRING = "1";

    /** SNMPĎx2(ifOctetsvyэ\`Ď) Description */
    public static final String SNMP_LEVEL2_DESCRIPTION = "SNMP ifOctets";
    public static final int SNMP_LEVEL2 = 2;
    public static final String SNMP_LEVEL2_CODE_STRING = "2";

    /** SNMPĎx3(CPUϕדvyэ\`Ď) Description */
    public static final String SNMP_LEVEL3_DESCRIPTION = "SNMP laLoad";
    public static final int SNMP_LEVEL3 = 3;
    public static final String SNMP_LEVEL3_CODE_STRING = "3";

    /** SNMPĎx4(Diskv̓vyэ\`Ď) Description */
    public static final String SNMP_LEVEL4_DESCRIPTION = "SNMP disk";
    public static final int SNMP_LEVEL4 = 4;
    public static final String SNMP_LEVEL4_CODE_STRING = "4";

    /**
     * SNMP}l[WSocket Timeout(ms)
     * ftHg6sec
     */
    public static final int SNMP_MANAGER_SOCKET_TIMEOUT = 6000;

    /**
     * SNMP}l[W̃gC
     */
    public static final int SNMP_MANAGER_SOCKET_RETRY = 3;

    /**
     * ErrorStatus "FormatError"
     *
     * Reference.
     *
     * Error Status Description
     *
     * -1   "FormatError"
     *  0   "NoError"
     *  1   "TooBig"
     *  2   "NoSuchName"
     *  3   "BadValue"
     *  4   "ReadOnly"
     *  5   "GenError"
     * Else "UnknownError
     */
    public static final int ERROR_STATUS_FORMATERROR = -1;

    /** Error Status "NoError"*/
    public static final int ERROR_STATUS_CORRECT = 0;

    /** Error Index Correct */
    public static final int ERROR_INDEX_CORRECT = 0;

    /** ErrorStatus "TooBig"*/
    public static final int ERROR_STATUS_TOOBIG = 1;

    /** ErrorStatus "NoSuchName"*/
    public static final int ERROR_STATUS_NOSUCHNAME = 2;

    /** ErrorStatus "BadValue"*/
    public static final int ERROR_STATUS_BADVALUE = 3;

    /** ErrorStatus "ReadOnly"*/
    public static final int ERROR_STATUS_READONLY = 4;

    /** ErrorStatus "GenError"*/
    public static final int ERROR_STATUS_GENERROR = 5;

    /** ErrorStatus "NoAcess"*/
    public static final int ERROR_STATUS_NOACCESS = 6;

    /** ErrorStatus "Wrong type"*/
    public static final int ERROR_STATUS_WRONG_TYPE = 7;

    /** ErrorStatus "Wrong length"*/
    public static final int ERROR_STATUS_WRONG_LENGTH = 8;

    /** ErrorStatus "Wrong value"*/
    public static final int ERROR_STATUS_WRONG_VALUE = 10;

    /** ErrorStatus "No creation"*/
    public static final int ERROR_STATUS_NO_CREATION = 11;

    /** ErrorStatus "Inconsistent value"*/
    public static final int ERROR_STATUS_INCONSISTENT_VALUE = 12;

    /** ErrorStatus "Resource UnAvailable"*/
    public static final int ERROR_STATUS_RESOURCE_UNAVAILABLE = 13;

    /** ErrorStatus "Commit failed"*/
    public static final int ERROR_STATUS_COMMIT_FAILED = 14;

    /** ErrorStatus "Undo failed"*/
    public static final int ERROR_STATUS_UNDO_FAILED = 15;

    /** ErrorStatus "Authorization error"*/
    public static final int ERROR_STATUS_AUTHORIZATION_ERROR = 16;

    /** ErrorStatus "No writable"*/
    public static final int ERROR_STATUS_NO_WRITABLE = 17;

    /** ErrorStatus "Inconsistent name"*/
    public static final int ERROR_STATUS_INCONSISTENT_NAME = 18;

    /** coldStart Generic Trap-code */
    public static final int COLDSTART = 0;

    /** warmStart Generic Trap-code */
    public static final int WARMSTART = 1;

    /** linkDown Generic Trap-code */
    public static final int LINKDOWN = 2;

    /** linkUp Generic Trap-code */
    public static final int LINKUP = 3;

    /** authenticationFailure Generic Trap-code */
    public static final int AUTHENTICATIONFAILURE = 4;

    /** egpNeighborLoss Generic Trap-code */
    public static final int EGPNEIGHBORLOS = 5;

    /** enterpriseSpecific Generic Trap-code */
    public static final int ENTERPRISESPECIFIC = 6;

    /** ifInOctets MINebg */
    public static final String IFINOCTETS_OID = "1.3.6.1.2.1.2.2.1.10";

    /** ifOutOctets MINebg */
    public static final String IFOUTOCTETS_OID = "1.3.6.1.2.1.2.2.1.16";

    /** Sysup Time OID */
    public static final String SNMP_SYSUPTIME_OID = "1.3.6.1.2.1.1.3.0";

    /**
     * TrapType defines the type of SNMPv2/SNMPv3 trap,
     * this is defined in the SNMPv2-MIB as snmpTrapOID.0
     * (.1.3.6.1.6.3.1.1.4.1.0) with an OID value of one
     *  of the following
     */
    public static final String SNMP_TRAP_OID = "1.3.6.1.6.3.1.1.4.1.0";

    /** coldStart OID */
    public static final String COLDSTART_OID = "1.3.6.1.6.3.1.1.5.1";

    /** warmStart OID */
    public static final String WARMSTART_OID = "1.3.6.1.6.3.1.1.5.2";

    /** linkDown OID */
    public static final String LINKDOWN_OID = "1.3.6.1.6.3.1.1.5.3";

    /** linkUp OID */
    public static final String LINKUP_OID = "1.3.6.1.6.3.1.1.5.4";

    /** authenticationFailure OID */
    public static final String AUTHENTICATIONFAILURE_OID =
        "1.3.6.1.6.3.1.1.5.5";

    /** egpNeighborLoss OID */
    public static final String EGPNEIGHBORLOS_OID = "1.3.6.1.6.3.1.1.5.6";

    /** enterpriseSpecific OID */
    public static final String ENTERPRISESPECIFIC_OID = "1.3.6.1.6.3.1.1.5.7";

    /** Unknown packet data unit OID */
    public static final String UNKONOWN_PACKET_DATA_UNIT =
        "1.3.6.1.6.3.11.2.1.3.0";

    /** Unknown packet data unit description */
    public static final String UNKONOWN_PACKET_DATA_UNIT_DESCRIPTION =
        "Unknown packet data unit";

    /** The value of the varbind shows the engine ID OID */
    public static final String SHOW_ENGINEID = "1.3.6.1.6.3.12.1.5.0";

    /** The value of the varbind shows the engine ID description */
    public static final String SHOW_ENGINEID_DESCRIPTION =
        "The value of the varbind shows the engine ID";

    /** Correct description */
    public static final String CORRECT_DESCRIPTION = "Normal";

    /** Unsupported security level of report OID */
    public static final String UNSUPPORTED_SECURITY_LEVEL =
        "1.3.6.1.6.3.15.1.1.1.0";

    /** Unsupported security level of report description */
    public static final String UNSUPPORTED_SECURITY_LEVEL_DESCRIPTION =
        "Unsupported security level";

    /** SNMP V3 Not inTime packet report OID */
    public static final String NOT_IN_TIME_PACKET = "1.3.6.1.6.3.15.1.1.2.0";

    /** SNMP V3 Not inTime packet report description */
    public static final String NOT_IN_TIME_PACKET_DESCRIPTION =
        "Not in time packet";

    /** SNMP V3 Unknown user name OID */
    public static final String UNKNOWN_USER_NAME = "1.3.6.1.6.3.15.1.1.3.0";

    /** SNMP V3 Unknown user name description */
    public static final String UNKNOWN_USER_NAME_DESCRIPTION =
        "Unknown user name";

    /** SNMP V3 Unknown engine ID OID */
    public static final String UNKNOWN_ENGINE_ID = "1.3.6.1.6.3.15.1.1.4.0";

    /** SNMP V3 Unknown engine ID description */
    public static final String UNKNOWN_ENGINE_ID_DESCRIPTION =
        "Unknown engine ID";

    /** SNMP V3 Wrong digest OID*/
    public static final String WRONG_DIGEST = "1.3.6.1.6.3.15.1.1.5.0";

    /** SNMP V3 Wrong digest description */
    public static final String WRONG_DIGEST_DESCRIPTION = "Wrong digest";

    /** SNMP V3 Descryption error OID */
    public static final String DECRYPTION_ERROR = "1.3.6.1.6.3.15.1.1.6.0";

    /** SNMP V3 Descryption error description */
    public static final String DECRYPTION_ERROR_DESCRIPTION =
        "Descryption error";
}
